summaryrefslogtreecommitdiffstats
path: root/konversation
diff options
context:
space:
mode:
authorSlávek Banko <slavek.banko@axis.cz>2013-09-03 19:57:57 +0200
committerSlávek Banko <slavek.banko@axis.cz>2013-09-03 19:57:57 +0200
commitc6220ec1fca1efbfa24dd18d51cc723ecf2c2934 (patch)
tree785683348dd5d3f62b8e28e39e926303dfd0ca62 /konversation
parent08034ff31e0282c677ea55b34cdef4802855fa96 (diff)
downloadkonversation-c6220ec1fca1efbfa24dd18d51cc723ecf2c2934.tar.gz
konversation-c6220ec1fca1efbfa24dd18d51cc723ecf2c2934.zip
Additional k => tde renaming and fixes
Diffstat (limited to 'konversation')
-rw-r--r--konversation/src/Makefile.am4
-rw-r--r--konversation/src/dccresumedialog.cpp4
-rw-r--r--konversation/src/dcctransfer.h2
-rw-r--r--konversation/src/dcctransferrecv.cpp6
-rw-r--r--konversation/src/dcctransferrecv.h2
-rw-r--r--konversation/src/linkaddressbook/addresseeitem.h2
-rw-r--r--konversation/src/nickinfo.h2
-rw-r--r--konversation/src/nicklistbehavior_preferencesui.ui2
-rw-r--r--konversation/src/nicksonline.cpp20
-rw-r--r--konversation/src/nicksonline.h2
10 files changed, 23 insertions, 23 deletions
diff --git a/konversation/src/Makefile.am b/konversation/src/Makefile.am
index 83ee4ea..6f370fa 100644
--- a/konversation/src/Makefile.am
+++ b/konversation/src/Makefile.am
@@ -33,7 +33,7 @@ konversation_SOURCES = konviface.skel konviconfigdialog.cpp konversationstatusba
connectionsettings.cpp connectionmanager.cpp awaymanager.cpp
konversation_COMPILE_FIRST = config/preferences_base.h
-konversation_LDADD = $(LIB_KIO) $(LIB_XSS) $(LIB_TDEABC) $(LIB_KIMIFACE) linkaddressbook/liblinkaddressbookui.la blowfish/libblowfish.la config/libkonversationconfig.la
+konversation_LDADD = $(LIB_TDEIO) $(LIB_XSS) $(LIB_TDEABC) $(LIB_KIMIFACE) linkaddressbook/liblinkaddressbookui.la blowfish/libblowfish.la config/libkonversationconfig.la
xdg_apps_DATA = konversation.desktop
@@ -41,7 +41,7 @@ xdg_apps_DATA = konversation.desktop
INCLUDES= -Ilinkaddressbook -I$(srcdir)/linkaddressbook -Iblowfish -I$(srcdir)/blowfish\
-Iconfig -I$(srcdir)/config $(all_includes)
# the library search path.
-konversation_LDFLAGS = $(all_libraries) $(KDE_RPATH) $(LIB_QT) -lDCOP $(LIB_TDECORE) $(LIB_TDEUI) -ltdefx $(LIB_KIO) -ltdetexteditor
+konversation_LDFLAGS = $(all_libraries) $(KDE_RPATH) $(LIB_QT) -lDCOP $(LIB_TDECORE) $(LIB_TDEUI) -ltdefx $(LIB_TDEIO) -ltdetexteditor
rcdir = $(kde_datadir)/konversation
rc_DATA = konversationui.rc eventsrc
diff --git a/konversation/src/dccresumedialog.cpp b/konversation/src/dccresumedialog.cpp
index 97d14a7..ecd81ce 100644
--- a/konversation/src/dccresumedialog.cpp
+++ b/konversation/src/dccresumedialog.cpp
@@ -142,8 +142,8 @@ void DccResumeDialog::updateDialogButtons() // slot
}
}
-// FIXME: kio-fy me!
-// taken and adapted from kio::renamedlg.cpp
+// FIXME: tdeio-fy me!
+// taken and adapted from tdeio::renamedlg.cpp
void DccResumeDialog::suggestNewName() // slot
{
TQString dotSuffix, suggestedName;
diff --git a/konversation/src/dcctransfer.h b/konversation/src/dcctransfer.h
index 25385bc..a504f38 100644
--- a/konversation/src/dcctransfer.h
+++ b/konversation/src/dcctransfer.h
@@ -43,7 +43,7 @@ class DccTransfer : public TQObject
{
Configuring = 0, // Not queud yet (this means that user can't see the item at this time)
Queued, // Newly added DCC, waiting user's response
- Preparing, // Opening KIO to write received data
+ Preparing, // Opening TDEIO to write received data
WaitingRemote, // Waiting for remote host's response
Connecting, // RECV: trying to connect to the server
Transferring,
diff --git a/konversation/src/dcctransferrecv.h b/konversation/src/dcctransferrecv.h
index ceb6fde..4d267bd 100644
--- a/konversation/src/dcctransferrecv.h
+++ b/konversation/src/dcctransferrecv.h
@@ -81,7 +81,7 @@ class DccTransferRecv : public DccTransfer
void startResume( unsigned long position );
protected slots:
- // Local KIO
+ // Local TDEIO
void slotLocalCanResume( TDEIO::Job* job, TDEIO::filesize_t size );
void slotLocalGotResult( TDEIO::Job* job );
void slotLocalReady( TDEIO::Job* job );
diff --git a/konversation/src/linkaddressbook/addresseeitem.h b/konversation/src/linkaddressbook/addresseeitem.h
index 1b7d93b..42d9d44 100644
--- a/konversation/src/linkaddressbook/addresseeitem.h
+++ b/konversation/src/linkaddressbook/addresseeitem.h
@@ -1,5 +1,5 @@
/*
- This file is part of libkabc.
+ This file is part of libtdeabc.
Copyright (c) 2001 Cornelius Schumacher <schumacher@kde.org>
This library is free software; you can redistribute it and/or
diff --git a/konversation/src/nickinfo.h b/konversation/src/nickinfo.h
index fbfa5c2..66bd96b 100644
--- a/konversation/src/nickinfo.h
+++ b/konversation/src/nickinfo.h
@@ -72,7 +72,7 @@ class NickInfo : public TQObject, public TDEShared
/// Return the Server object that owns this NickInfo object.
Server* getServer() const;
- /// Return the kabc (kaddressbook) contact for this nick
+ /// Return the tdeabc (kaddressbook) contact for this nick
TDEABC::Addressee getAddressee() const;
/** Set properties of NickInfo object. */
diff --git a/konversation/src/nicklistbehavior_preferencesui.ui b/konversation/src/nicklistbehavior_preferencesui.ui
index 7d8335f..1b0b673 100644
--- a/konversation/src/nicklistbehavior_preferencesui.ui
+++ b/konversation/src/nicklistbehavior_preferencesui.ui
@@ -154,7 +154,7 @@ the Free Software Foundation; either version 2 of the License, or
<layoutdefaults spacing="6" margin="11"/>
<layoutfunctions spacing="KDialog::spacingHint" margin="KDialog::marginHint"/>
<includehints>
- <includehint>klistview.h</includehint>
+ <includehint>tdelistview.h</includehint>
<includehint>klineedit.h</includehint>
</includehints>
</UI>
diff --git a/konversation/src/nicksonline.cpp b/konversation/src/nicksonline.cpp
index 68ccf2a..496e178 100644
--- a/konversation/src/nicksonline.cpp
+++ b/konversation/src/nicksonline.cpp
@@ -59,7 +59,7 @@ NicksOnline::NicksOnline(TQWidget* parent): ChatWindow(parent)
m_whoisRequested = true;
m_nickListView->addColumn(i18n("Network/Nickname/Channel"));
- m_kabcIconSet = TDEGlobal::iconLoader()->loadIconSet("kaddressbook",TDEIcon::Small);
+ m_tdeabcIconSet = TDEGlobal::iconLoader()->loadIconSet("kaddressbook",TDEIcon::Small);
m_nickListView->addColumn(i18n("Additional Information"));
m_nickListView->setFullWidth(true);
m_nickListView->setRootIsDecorated(true);
@@ -109,20 +109,20 @@ NicksOnline::NicksOnline(TQWidget* parent): ChatWindow(parent)
"Click to create, view, or edit the KAddressBook entry associated with the nickname "
"selected above.");
TQWhatsThis::add(m_editContactButton, editContactButtonWT);
- m_editContactButton->setIconSet(m_kabcIconSet);
+ m_editContactButton->setIconSet(m_tdeabcIconSet);
m_changeAssociationButton = new TQPushButton(i18n("&Change Association..."),
buttonBox, "nicksonline_changeassociation_button");
TQString changeAssociationButtonWT = i18n(
"Click to associate the nickname selected above with an entry in KAddressBook.");
TQWhatsThis::add(m_changeAssociationButton, changeAssociationButtonWT);
- m_changeAssociationButton->setIconSet(m_kabcIconSet);
+ m_changeAssociationButton->setIconSet(m_tdeabcIconSet);
m_deleteAssociationButton = new TQPushButton(i18n("&Delete Association"),
buttonBox, "nicksonline_deleteassociation_button");
TQString deleteAssociationButtonWT = i18n(
"Click to remove the association between the nickname selected above and a "
"KAddressBook entry.");
TQWhatsThis::add(m_deleteAssociationButton, deleteAssociationButtonWT);
- m_deleteAssociationButton->setIconSet(m_kabcIconSet);
+ m_deleteAssociationButton->setIconSet(m_tdeabcIconSet);
connect(m_editContactButton, TQT_SIGNAL(clicked()),
this, TQT_SLOT(slotEditContactButton_Clicked()));
@@ -333,10 +333,10 @@ void NicksOnline::updateServerOnlineList(Server* servr)
}
// Set Kabc icon if the nick is associated with an addressbook entry.
if (!addressee.isEmpty())
- nickRoot->setPixmap(nlvcKabc, m_kabcIconSet.pixmap(
+ nickRoot->setPixmap(nlvcKabc, m_tdeabcIconSet.pixmap(
TQIconSet::Small, TQIconSet::Normal, TQIconSet::On));
else
- nickRoot->setPixmap(nlvcKabc, m_kabcIconSet.pixmap(
+ nickRoot->setPixmap(nlvcKabc, m_tdeabcIconSet.pixmap(
TQIconSet::Small, TQIconSet::Disabled, TQIconSet::Off));
TQStringList channelList = server->getNickChannels(nickname);
@@ -405,10 +405,10 @@ void NicksOnline::updateServerOnlineList(Server* servr)
nickRoot->setText(nlvcAdditionalInfo, nickAdditionalInfo);
// Set Kabc icon if the nick is associated with an addressbook entry.
if (!addressee.isEmpty())
- nickRoot->setPixmap(nlvcKabc, m_kabcIconSet.pixmap(
+ nickRoot->setPixmap(nlvcKabc, m_tdeabcIconSet.pixmap(
TQIconSet::Small, TQIconSet::Normal, TQIconSet::On));
else
- nickRoot->setPixmap(nlvcKabc, m_kabcIconSet.pixmap(
+ nickRoot->setPixmap(nlvcKabc, m_tdeabcIconSet.pixmap(
TQIconSet::Small, TQIconSet::Disabled, TQIconSet::Off));
}
}
@@ -948,12 +948,12 @@ void NicksOnline::refreshItem(TQListViewItem* item)
break;
case nsNoAddress:
{
- item->setPixmap(nlvcKabc, m_kabcIconSet.pixmap(
+ item->setPixmap(nlvcKabc, m_tdeabcIconSet.pixmap(
TQIconSet::Small, TQIconSet::Disabled, TQIconSet::Off)); break;
}
case nsHasAddress:
{
- item->setPixmap(nlvcKabc, m_kabcIconSet.pixmap(
+ item->setPixmap(nlvcKabc, m_tdeabcIconSet.pixmap(
TQIconSet::Small, TQIconSet::Normal, TQIconSet::On)); break;
}
}
diff --git a/konversation/src/nicksonline.h b/konversation/src/nicksonline.h
index 4581b2c..414c774 100644
--- a/konversation/src/nicksonline.h
+++ b/konversation/src/nicksonline.h
@@ -254,7 +254,7 @@ class NicksOnline : public ChatWindow
// Timer for refreshing display and generating WHOISes.
TQTimer* m_timer;
// Addressbook icon.
- TQIconSet m_kabcIconSet;
+ TQIconSet m_tdeabcIconSet;
/* Set to False every 8 seconds so that we generate a WHOIS on watch nicks that
lack information.*/
bool m_whoisRequested;
diff --git a/konversation/src/dcctransferrecv.cpp b/konversation/src/dcctransferrecv.cpp
index 536eab0..00a98ed 100644
--- a/konversation/src/dcctransferrecv.cpp
+++ b/konversation/src/dcctransferrecv.cpp
@@ -281,7 +281,7 @@ void DccTransferRecv::prepareLocalKio( bool overwrite, bool resume, TDEIO::fileo
if ( !transferJob )
{
kdDebug() << "DccTransferRecv::prepareLocalKio(): TDEIO::put() returned NULL. what happened?" << endl;
- failed( i18n( "Could not create a KIO instance" ) );
+ failed( i18n( "Could not create a TDEIO instance" ) );
return;
}
@@ -642,7 +642,7 @@ void DccTransferRecv::slotLocalWriteDone() // <-WriteCacheHandler::done()
void DccTransferRecv::slotLocalGotWriteError( const TQString& errorString )
{
kdDebug() << "DccTransferRecv::slotLocalGotWriteError()" << endl;
- failed( i18n( "KIO error: %1" ).arg( errorString ) );
+ failed( i18n( "TDEIO error: %1" ).arg( errorString ) );
}
void DccTransferRecv::startConnectionTimer( int sec )
@@ -736,7 +736,7 @@ bool DccTransferRecvWriteCacheHandler::write( bool force )
void DccTransferRecvWriteCacheHandler::close() // public
{
kdDebug() << "DTRWriteCacheHandler::close()" << endl;
- write( true ); // write once if kio is ready to write
+ write( true ); // write once if tdeio is ready to write
m_transferJob->setAsyncDataEnabled( m_writeAsyncMode = false );
kdDebug() << "DTRWriteCacheHandler::close(): switched to synchronized mode." << endl;
kdDebug() << "DTRWriteCacheHandler::close(): flushing... (remaining caches: " << m_cacheList.count() << ")" << endl;